summaryrefslogtreecommitdiff
path: root/src/d/actor/d_a_ks.cpp
diff options
context:
space:
mode:
authorLagoLunatic <LagoLunatic@users.noreply.github.com>2026-05-26 00:11:58 -0400
committerGitHub <noreply@github.com>2026-05-26 00:11:58 -0400
commit102042628fa139f4e509251bdd9095493f031e28 (patch)
treea5b37fcd76d8c0105f2e9b379b7e2daa7eae2266 /src/d/actor/d_a_ks.cpp
parent79277cb2b2672104b87172d8ff620f923f450658 (diff)
Process profiles and enums cleanup (#1031)
* Fix some profile comments * Add missing static for local visibility data * Move proc name and draw priority enums to f_pc * Add _e suffix to daObjBarrier_c proc enum * Change proc name enum format to match TP * Change draw prio enum format to match TP * Change ItemNo enum format, finish fixing item names * Revert static for cb1 hio * Clean up formatting of profile comments * Fix comment alignment
Diffstat (limited to 'src/d/actor/d_a_ks.cpp')
-rw-r--r--src/d/actor/d_a_ks.cpp28
1 files changed, 13 insertions, 15 deletions
diff --git a/src/d/actor/d_a_ks.cpp b/src/d/actor/d_a_ks.cpp
index 34f667fe..79f2a930 100644
--- a/src/d/actor/d_a_ks.cpp
+++ b/src/d/actor/d_a_ks.cpp
@@ -5,8 +5,6 @@
#include "d/dolzel_rel.h" // IWYU pragma: keep
#include "d/actor/d_a_ks.h"
-#include "d/d_procname.h"
-#include "d/d_priority.h"
#include "d/d_com_inf_game.h"
#include "d/d_s_play.h"
#include "f_op/f_op_camera.h"
@@ -213,7 +211,7 @@ BOOL ks_kuttuki_check(ks_class* i_this) {
void gm_birth_delet(ks_class* i_this) {
if (i_this->mGmID) {
gm_class* i_gm = (gm_class*)fopAcM_SearchByID(i_this->mGmID);
- if (i_gm && fopAc_IsActor(i_gm) && fopAcM_GetName(i_gm) == PROC_GM && i_gm->m31E > 0) {
+ if (i_gm && fopAc_IsActor(i_gm) && fopAcM_GetName(i_gm) == fpcNm_GM_e && i_gm->m31E > 0) {
i_gm->m31E--;
}
}
@@ -1187,7 +1185,7 @@ void* tsubo_search(void* param_1, void* i_data) {
ks_class* i_this = (ks_class*)i_data;
fopAc_ac_c* actor = &i_this->actor;
int r0 = 0;
- if (r0 < 100 && fopAc_IsActor(param_1) && (fopAcM_GetName(param_1) == PROC_TSUBO)) {
+ if (r0 < 100 && fopAc_IsActor(param_1) && (fopAcM_GetName(param_1) == fpcNm_TSUBO_e)) {
fopAc_ac_c* tsubo_actor = (fopAc_ac_c*)param_1;
if (std::fabsf(tsubo_actor->current.pos.x - actor->current.pos.x) < 20.0f &&
@@ -1277,7 +1275,7 @@ void action_tubo_search(ks_class* i_this) {
actor->shape_angle = actor->current.angle;
actor->shape_angle.x = 0;
- fopAcM_create(PROC_KS, 3, &local_24, fopAcM_GetRoomNo(actor), &actor->shape_angle, &actor->scale, 0);
+ fopAcM_create(fpcNm_KS_e, 3, &local_24, fopAcM_GetRoomNo(actor), &actor->shape_angle, &actor->scale, 0);
}
fopAcM_delete(actor);
@@ -1360,7 +1358,7 @@ static BOOL daKS_Execute(ks_class* i_this) {
bool bVar5 = false;
if (gmActor && ((fopAcM_GetParam(gmActor) & 0xff0000) == 0xff0000 || (fopAcM_GetParam(gmActor) & 0xff0000) == 0)) {
- if (fopAcM_GetName(gmActor) == PROC_GM) {
+ if (fopAcM_GetName(gmActor) == fpcNm_GM_e) {
if (gmActor->health <= 0) {
bVar5 = true;
}
@@ -1604,7 +1602,7 @@ static cPhs_State daKS_Create(fopAc_ac_c* i_this) {
i_this->shape_angle = i_this->current.angle;
i_this->shape_angle.x = 0;
- fopAcM_create(PROC_KS, param, &local_4c, fopAcM_GetRoomNo(i_this), &i_this->shape_angle, &i_this->scale, 0);
+ fopAcM_create(fpcNm_KS_e, param, &local_4c, fopAcM_GetRoomNo(i_this), &i_this->shape_angle, &i_this->scale, 0);
}
return cPhs_ERROR_e;
@@ -1719,7 +1717,7 @@ static cPhs_State daKS_Create(fopAc_ac_c* i_this) {
}
fopAc_ac_c* gm_actor = fopAcM_SearchByID(a_this->mGmID);
- if (gm_actor && fopAc_IsActor(gm_actor) && fopAcM_GetName(gm_actor) == PROC_GM && a_this->m2C8 == 5) {
+ if (gm_actor && fopAc_IsActor(gm_actor) && fopAcM_GetName(gm_actor) == fpcNm_GM_e && a_this->m2C8 == 5) {
i_this->current.angle.y += cM_rndFX(8192.0f);
i_this->speedF = cM_rndF(6.0f) + 34.0f;
i_this->speed.y = cM_rndF(8.0f) + 22.0f;
@@ -1775,18 +1773,18 @@ static actor_method_class l_daKS_Method = {
};
actor_process_profile_definition g_profile_KS = {
/* LayerID */ fpcLy_CURRENT_e,
/* ListID */ 0x0007,
/* ListPrio */ fpcPi_CURRENT_e,
/* ProcName */ PROC_KS,
/* Proc SubMtd */ &g_fpcLf_Method.base,
/* Size */ sizeof(ks_class),
- /* SizeOther */ 0,
+ /* Size Other */ 0,
/* Parameters */ 0,
/* Leaf SubMtd */ &g_fopAc_Method.base,
- /* Priority */ PRIO_KS,
+ /* Draw Prio */ fpcDwPi_KS_e,
/* Actor SubMtd */ &l_daKS_Method,
/* Status */ fopAcStts_CULL_e | fopAcStts_UNK40000_e,
/* Group */ fopAc_ENV_e,
- /* CullType */ fopAc_CULLBOX_CUSTOM_e,
+ /* Cull Type */ fopAc_CULLBOX_CUSTOM_e,
};
@@ -1775,18 +1773,18 @@ static actor_method_class l_daKS_Method = {
};
actor_process_profile_definition g_profile_KS = {
- /* LayerID */ fpcLy_CURRENT_e,
- /* ListID */ 0x0007,
- /* ListPrio */ fpcPi_CURRENT_e,
- /* ProcName */ PROC_KS,
+ /* Layer ID */ fpcLy_CURRENT_e,
+ /* List ID */ 0x0007,
+ /* List Prio */ fpcPi_CURRENT_e,
+ /* Proc Name */ fpcNm_KS_e,
/* Proc SubMtd */ &g_fpcLf_Method.base,
/* Size */ sizeof(ks_class),